@@ -1,4 +1,4 @@
-import xmltodict
+import xmltodict, re
 
 from bionetgen.main import BioNetGen
 from tempfile import TemporaryFile
@@ -7,6 +7,7 @@ from .bngfile import BNGFile
 from .xmlparsers import ParameterBlockXML, CompartmentBlockXML, ObservableBlockXML
 from .xmlparsers import SpeciesBlockXML, MoleculeTypeBlockXML, FunctionBlockXML
 from .xmlparsers import RuleBlockXML
+from .blocks import ActionBlock
 
 # This allows access to the CLIs config setup
 app = BioNetGen()
@@ -36,7 +37,8 @@ class BNGParser:
         parses given xml string and adds everything to a given model object
     """
 
-    def __init__(self, path, BNGPATH=def_bng_path) -> None:
+    def __init__(self, path, BNGPATH=def_bng_path, parse_actions=True) -> None:
+        self.to_parse_actions = parse_actions
         self.bngfile = BNGFile(path)
 
     def parse_model(self, model_obj) -> None:
@@ -45,6 +47,8 @@ class BNGParser:
         parser
         """
         self._parse_model_bngpl(model_obj)
+        if self.to_parse_actions:
+            self.parse_actions(model_obj)
 
     def _parse_model_bngpl(self, model_obj) -> None:
         # get file path
@@ -72,6 +76,53 @@ class BNGParser:
             print("The extension of {} is not supported".format(model_file))
             raise NotImplementedError
 
+    def parse_actions(self, model_obj):
+        if len(self.bngfile.parsed_actions) > 0:
+            ablock = ActionBlock()
+            # we have actions in file, let's get them
+            for action in self.bngfile.parsed_actions:
+                action = re.sub("\#.*", "", action)
+                action = re.sub("\s", "", action)
+                if len(action) == 0:
+                    continue
+                m = re.match(r"^\s*(\S+)\(\s*(\S*)\s*\)(\;)?\s*(\#\s*\S*)?\s*", action)
+                if m is not None:
+                    # here we have an action
+                    atype = m.group(1)
+                    in_parans = m.group(2)
+                    if len(in_parans) > 0:
+                        # in paranthesis group can have curly or square braces
+                        m = re.match(r"\{(\S*)\}", in_parans)
+                        arg_tuples = []
+                        if m is not None:
+                            # this is a normal action
+                            arg_list_str = m.group(1)
+                            arg_list = arg_list_str.split(",")
+                            for arg_str in arg_list:
+                                m = re.match(r"(\S*)\=\>(\S*)", arg_str)
+                                if m is not None:
+                                    # add to arg_tuples
+                                    arg = m.group(1)
+                                    val = m.group(2)
+                                    arg_tuples.append((arg, val))
+                        else:
+                            m = re.match(r"\[(\S*)\]", in_parans)
+                            if m is not None:
+                                # this is a list of items
+                                arg_list_str = m.group(1)
+                            else:
+                                # what we have in parantheses has to
+                                # be a simple list of arguments
+                                arg_list_str = in_parans
+                            arg_list = arg_list_str.split(",")
+                            for arg_str in arg_list:
+                                # add to arg_tuples
+                                arg_tuples.append((arg_str, None))
+                        ablock.add_action(atype, arg_tuples)
+                    else:
+                        ablock.add_action(atype, [])
+        model_obj.add_block(ablock)
+
     def parse_xml(self, xml_str, model_obj) -> None:
         xml_dict = xmltodict.parse(xml_str)
         model_obj.xml_dict = xml_dict
